@@ -15,11 +15,7 @@ class FrozenListMixin:
 
     def test_iface(self) -> None:
         for name in set(dir(MutableSequence)) - self.SKIP_METHODS:
-            if (
-                (name.startswith('_') and
-                 not name.endswith('_')) or
-                name == '__class_getitem__'
-            ):
+            if name.startswith('_') and not name.endswith('_'):
                 continue
             assert hasattr(self.FrozenList, name)
 
